@@ -4,8 +4,8 @@
 # Released under the MIT License.
 # Copyright, 2024, by Samuel Williams.
 
-require '../../lib/async/container'
-require 'async/io/host_endpoint'
+require "../../lib/async/container"
+require "io/endpoint/host_endpoint"
 
 Console.logger.debug!
 
@@ -24,7 +24,7 @@ class Controller < Async::Container::Controller
 	def initialize(...)
 		super
 		
-		@endpoint = Async::IO::Endpoint.tcp("localhost", 8080)
+		@endpoint = ::IO::Endpoint.tcp("localhost", 8080)
 		@bound_endpoint = nil
 	end
 	
