@@ -3,13 +3,14 @@
 # Released under the MIT License.
 # Copyright, 2017-2024, by Samuel Williams.
 
-source 'https://rubygems.org'
+source "https://rubygems.org"
 
 gemspec
 
 group :maintenance, optional: true do
 	gem "bake-gem"
 	gem "bake-modernize"
+	gem "bake-releases"
 	
 	gem "utopia-project"
 end
@@ -17,6 +18,10 @@ end
 group :test do
 	gem "sus"
 	gem "covered"
+	gem "decode"
+	gem "rubocop"
+	
+	gem "metrics"
 	
 	gem "bake-test"
 	gem "bake-test-external"
