@@ -3,8 +3,8 @@
 # Released under the MIT License.
 # Copyright, 2021-2024, by Samuel Williams.
 
-source 'https://rubygems.org'
+source "https://rubygems.org"
 
 eval_gemfile "../gems.rb"
 
-gem 'async', git: "https://github.com/socketry/async"
+gem "async", git: "https://github.com/socketry/async"
